@@ -11,4 +11,4 @@ This library has two goals:
 from .deserialize import load
 from .errors import DeserializeError
 from .serialize import dump
-from .typedefs import OptionalProperty, is_missing
+from .typedefs import OptionalProperty, get, is_missing
